# Changelog

## Version 0.5.0

- Migrate from GitLab to GitHub
- Migrate from tox/setuptools to uv/hatchling
- Drop Python 3.8 and 3.9 support; require Python 3.10+
- Replace flake8/black/isort with ruff in pre-commit hooks

## Version 0.4.0

- Add py.typed

## Version 0.3.0 (development)

- fix parsing of the response when setting a target temperature

## Version 0.2.2 (development)

- various communication fixes
- allow disabling humidity control
- change package name

## Version 0.2.1 (development)

- feat: Initial climate_chamber
